;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "bash-completion" "20250721.2026"
  "Bash completion for the shell buffer."
  '((emacs "25.3"))
  :url "http://github.com/szermatt/emacs-bash-completion"
  :commit "762f28fefba487e15d626691310f3194804eb71a"
  :revdesc "762f28fefba4"
  :keywords '("convenience" "unix")
  :authors '(("Stephane Zermatten" . "szermatt@gmx.net"))
  :maintainers '(("Stephane Zermatten" . "szermatt@gmail.com")))
